%%
%%  Copyright (c) 2005 Dan Gudmundsson
%%
%%  See the file "license.terms" for information on usage and redistribution
%%  of this file, and for a DISCLAIMER OF ALL WARRANTIES.
%% 
%%     $Id$
%%
-define(glBlendColor, ?SDL_OPENGL_EXTS_HRL + 0).
-define(glBlendEquation, ?SDL_OPENGL_EXTS_HRL + 1).
-define(glDrawRangeElements, ?SDL_OPENGL_EXTS_HRL + 2).
-define(glColorTable, ?SDL_OPENGL_EXTS_HRL + 3).
-define(glColorTableParameterfv, ?SDL_OPENGL_EXTS_HRL + 4).
-define(glColorTableParameteriv, ?SDL_OPENGL_EXTS_HRL + 5).
-define(glCopyColorTable, ?SDL_OPENGL_EXTS_HRL + 6).
-define(glGetColorTable, ?SDL_OPENGL_EXTS_HRL + 7).
-define(glGetColorTableParameterfv, ?SDL_OPENGL_EXTS_HRL + 8).
-define(glGetColorTableParameteriv, ?SDL_OPENGL_EXTS_HRL + 9).
-define(glColorSubTable, ?SDL_OPENGL_EXTS_HRL + 10).
-define(glCopyColorSubTable, ?SDL_OPENGL_EXTS_HRL + 11).
-define(glConvolutionFilter1D, ?SDL_OPENGL_EXTS_HRL + 12).
-define(glConvolutionFilter2D, ?SDL_OPENGL_EXTS_HRL + 13).
-define(glConvolutionParameterf, ?SDL_OPENGL_EXTS_HRL + 14).
-define(glConvolutionParameterfv, ?SDL_OPENGL_EXTS_HRL + 15).
-define(glConvolutionParameteri, ?SDL_OPENGL_EXTS_HRL + 16).
-define(glConvolutionParameteriv, ?SDL_OPENGL_EXTS_HRL + 17).
-define(glCopyConvolutionFilter1D, ?SDL_OPENGL_EXTS_HRL + 18).
-define(glCopyConvolutionFilter2D, ?SDL_OPENGL_EXTS_HRL + 19).
-define(glGetConvolutionFilter, ?SDL_OPENGL_EXTS_HRL + 20).
-define(glGetConvolutionParameterfv, ?SDL_OPENGL_EXTS_HRL + 21).
-define(glGetConvolutionParameteriv, ?SDL_OPENGL_EXTS_HRL + 22).
-define(glGetSeparableFilter, ?SDL_OPENGL_EXTS_HRL + 23).
-define(glSeparableFilter2D, ?SDL_OPENGL_EXTS_HRL + 24).
-define(glGetHistogram, ?SDL_OPENGL_EXTS_HRL + 25).
-define(glGetHistogramParameterfv, ?SDL_OPENGL_EXTS_HRL + 26).
-define(glGetHistogramParameteriv, ?SDL_OPENGL_EXTS_HRL + 27).
-define(glGetMinmax, ?SDL_OPENGL_EXTS_HRL + 28).
-define(glGetMinmaxParameterfv, ?SDL_OPENGL_EXTS_HRL + 29).
-define(glGetMinmaxParameteriv, ?SDL_OPENGL_EXTS_HRL + 30).
-define(glHistogram, ?SDL_OPENGL_EXTS_HRL + 31).
-define(glMinmax, ?SDL_OPENGL_EXTS_HRL + 32).
-define(glResetHistogram, ?SDL_OPENGL_EXTS_HRL + 33).
-define(glResetMinmax, ?SDL_OPENGL_EXTS_HRL + 34).
-define(glTexImage3D, ?SDL_OPENGL_EXTS_HRL + 35).
-define(glTexSubImage3D, ?SDL_OPENGL_EXTS_HRL + 36).
-define(glCopyTexSubImage3D, ?SDL_OPENGL_EXTS_HRL + 37).
-define(glActiveTexture, ?SDL_OPENGL_EXTS_HRL + 38).
-define(glClientActiveTexture, ?SDL_OPENGL_EXTS_HRL + 39).
-define(glMultiTexCoord1dv, ?SDL_OPENGL_EXTS_HRL + 40).
-define(glMultiTexCoord1fv, ?SDL_OPENGL_EXTS_HRL + 41).
-define(glMultiTexCoord1iv, ?SDL_OPENGL_EXTS_HRL + 42).
-define(glMultiTexCoord1sv, ?SDL_OPENGL_EXTS_HRL + 43).
-define(glMultiTexCoord2dv, ?SDL_OPENGL_EXTS_HRL + 44).
-define(glMultiTexCoord2fv, ?SDL_OPENGL_EXTS_HRL + 45).
-define(glMultiTexCoord2iv, ?SDL_OPENGL_EXTS_HRL + 46).
-define(glMultiTexCoord2sv, ?SDL_OPENGL_EXTS_HRL + 47).
-define(glMultiTexCoord3dv, ?SDL_OPENGL_EXTS_HRL + 48).
-define(glMultiTexCoord3fv, ?SDL_OPENGL_EXTS_HRL + 49).
-define(glMultiTexCoord3iv, ?SDL_OPENGL_EXTS_HRL + 50).
-define(glMultiTexCoord3sv, ?SDL_OPENGL_EXTS_HRL + 51).
-define(glMultiTexCoord4dv, ?SDL_OPENGL_EXTS_HRL + 52).
-define(glMultiTexCoord4fv, ?SDL_OPENGL_EXTS_HRL + 53).
-define(glMultiTexCoord4iv, ?SDL_OPENGL_EXTS_HRL + 54).
-define(glMultiTexCoord4sv, ?SDL_OPENGL_EXTS_HRL + 55).
-define(glLoadTransposeMatrixf, ?SDL_OPENGL_EXTS_HRL + 56).
-define(glLoadTransposeMatrixd, ?SDL_OPENGL_EXTS_HRL + 57).
-define(glMultTransposeMatrixf, ?SDL_OPENGL_EXTS_HRL + 58).
-define(glMultTransposeMatrixd, ?SDL_OPENGL_EXTS_HRL + 59).
-define(glSampleCoverage, ?SDL_OPENGL_EXTS_HRL + 60).
-define(glCompressedTexImage3D, ?SDL_OPENGL_EXTS_HRL + 61).
-define(glCompressedTexImage2D, ?SDL_OPENGL_EXTS_HRL + 62).
-define(glCompressedTexImage1D, ?SDL_OPENGL_EXTS_HRL + 63).
-define(glCompressedTexSubImage3D, ?SDL_OPENGL_EXTS_HRL + 64).
-define(glCompressedTexSubImage2D, ?SDL_OPENGL_EXTS_HRL + 65).
-define(glCompressedTexSubImage1D, ?SDL_OPENGL_EXTS_HRL + 66).
-define(glGetCompressedTexImage, ?SDL_OPENGL_EXTS_HRL + 67).
-define(glBlendFuncSeparate, ?SDL_OPENGL_EXTS_HRL + 68).
-define(glFogCoordf, ?SDL_OPENGL_EXTS_HRL + 69).
-define(glFogCoordfv, ?SDL_OPENGL_EXTS_HRL + 70).
-define(glFogCoordd, ?SDL_OPENGL_EXTS_HRL + 71).
-define(glFogCoorddv, ?SDL_OPENGL_EXTS_HRL + 72).
-define(glFogCoordPointer, ?SDL_OPENGL_EXTS_HRL + 73).
-define(glMultiDrawArrays, ?SDL_OPENGL_EXTS_HRL + 74).
-define(glPointParameterf, ?SDL_OPENGL_EXTS_HRL + 75).
-define(glPointParameterfv, ?SDL_OPENGL_EXTS_HRL + 76).
-define(glPointParameteri, ?SDL_OPENGL_EXTS_HRL + 77).
-define(glPointParameteriv, ?SDL_OPENGL_EXTS_HRL + 78).
-define(glSecondaryColor3bv, ?SDL_OPENGL_EXTS_HRL + 79).
-define(glSecondaryColor3dv, ?SDL_OPENGL_EXTS_HRL + 80).
-define(glSecondaryColor3fv, ?SDL_OPENGL_EXTS_HRL + 81).
-define(glSecondaryColor3iv, ?SDL_OPENGL_EXTS_HRL + 82).
-define(glSecondaryColor3sv, ?SDL_OPENGL_EXTS_HRL + 83).
-define(glSecondaryColor3ubv, ?SDL_OPENGL_EXTS_HRL + 84).
-define(glSecondaryColor3uiv, ?SDL_OPENGL_EXTS_HRL + 85).
-define(glSecondaryColor3usv, ?SDL_OPENGL_EXTS_HRL + 86).
-define(glSecondaryColorPointer, ?SDL_OPENGL_EXTS_HRL + 87).
-define(glWindowPos2dv, ?SDL_OPENGL_EXTS_HRL + 88).
-define(glWindowPos2fv, ?SDL_OPENGL_EXTS_HRL + 89).
-define(glWindowPos2iv, ?SDL_OPENGL_EXTS_HRL + 90).
-define(glWindowPos2sv, ?SDL_OPENGL_EXTS_HRL + 91).
-define(glWindowPos3dv, ?SDL_OPENGL_EXTS_HRL + 92).
-define(glWindowPos3fv, ?SDL_OPENGL_EXTS_HRL + 93).
-define(glWindowPos3iv, ?SDL_OPENGL_EXTS_HRL + 94).
-define(glWindowPos3sv, ?SDL_OPENGL_EXTS_HRL + 95).
-define(glGenQueries, ?SDL_OPENGL_EXTS_HRL + 96).
-define(glDeleteQueries, ?SDL_OPENGL_EXTS_HRL + 97).
-define(glIsQuery, ?SDL_OPENGL_EXTS_HRL + 98).
-define(glBeginQuery, ?SDL_OPENGL_EXTS_HRL + 99).
-define(glEndQuery, ?SDL_OPENGL_EXTS_HRL + 100).
-define(glGetQueryiv, ?SDL_OPENGL_EXTS_HRL + 101).
-define(glGetQueryObjectiv, ?SDL_OPENGL_EXTS_HRL + 102).
-define(glGetQueryObjectuiv, ?SDL_OPENGL_EXTS_HRL + 103).
-define(glBindBuffer, ?SDL_OPENGL_EXTS_HRL + 104).
-define(glDeleteBuffers, ?SDL_OPENGL_EXTS_HRL + 105).
-define(glGenBuffers, ?SDL_OPENGL_EXTS_HRL + 106).
-define(glIsBuffer, ?SDL_OPENGL_EXTS_HRL + 107).
-define(glBufferData, ?SDL_OPENGL_EXTS_HRL + 108).
-define(glBufferSubData, ?SDL_OPENGL_EXTS_HRL + 109).
-define(glGetBufferSubData, ?SDL_OPENGL_EXTS_HRL + 110).
-define(glUnmapBuffer, ?SDL_OPENGL_EXTS_HRL + 111).
-define(glGetBufferParameteriv, ?SDL_OPENGL_EXTS_HRL + 112).
-define(glGetBufferPointerv, ?SDL_OPENGL_EXTS_HRL + 113).
-define(glBlendEquationSeparate, ?SDL_OPENGL_EXTS_HRL + 114).
-define(glDrawBuffers, ?SDL_OPENGL_EXTS_HRL + 115).
-define(glStencilOpSeparate, ?SDL_OPENGL_EXTS_HRL + 116).
-define(glStencilFuncSeparate, ?SDL_OPENGL_EXTS_HRL + 117).
-define(glStencilMaskSeparate, ?SDL_OPENGL_EXTS_HRL + 118).
-define(glAttachShader, ?SDL_OPENGL_EXTS_HRL + 119).
-define(glBindAttribLocation, ?SDL_OPENGL_EXTS_HRL + 120).
-define(glCompileShader, ?SDL_OPENGL_EXTS_HRL + 121).
-define(glCreateProgram, ?SDL_OPENGL_EXTS_HRL + 122).
-define(glCreateShader, ?SDL_OPENGL_EXTS_HRL + 123).
-define(glDeleteProgram, ?SDL_OPENGL_EXTS_HRL + 124).
-define(glDeleteShader, ?SDL_OPENGL_EXTS_HRL + 125).
-define(glDetachShader, ?SDL_OPENGL_EXTS_HRL + 126).
-define(glDisableVertexAttribArray, ?SDL_OPENGL_EXTS_HRL + 127).
-define(glEnableVertexAttribArray, ?SDL_OPENGL_EXTS_HRL + 128).
-define(glGetActiveAttrib, ?SDL_OPENGL_EXTS_HRL + 129).
-define(glGetActiveUniform, ?SDL_OPENGL_EXTS_HRL + 130).
-define(glGetAttachedShaders, ?SDL_OPENGL_EXTS_HRL + 131).
-define(glGetAttribLocation, ?SDL_OPENGL_EXTS_HRL + 132).
-define(glGetProgramiv, ?SDL_OPENGL_EXTS_HRL + 133).
-define(glGetProgramInfoLog, ?SDL_OPENGL_EXTS_HRL + 134).
-define(glGetShaderiv, ?SDL_OPENGL_EXTS_HRL + 135).
-define(glGetShaderInfoLog, ?SDL_OPENGL_EXTS_HRL + 136).
-define(glGetShaderSource, ?SDL_OPENGL_EXTS_HRL + 137).
-define(glGetUniformLocation, ?SDL_OPENGL_EXTS_HRL + 138).
-define(glGetUniformfv, ?SDL_OPENGL_EXTS_HRL + 139).
-define(glGetUniformiv, ?SDL_OPENGL_EXTS_HRL + 140).
-define(glGetVertexAttribdv, ?SDL_OPENGL_EXTS_HRL + 141).
-define(glGetVertexAttribfv, ?SDL_OPENGL_EXTS_HRL + 142).
-define(glGetVertexAttribiv, ?SDL_OPENGL_EXTS_HRL + 143).
-define(glGetVertexAttribPointerv, ?SDL_OPENGL_EXTS_HRL + 144).
-define(glIsProgram, ?SDL_OPENGL_EXTS_HRL + 145).
-define(glIsShader, ?SDL_OPENGL_EXTS_HRL + 146).
-define(glLinkProgram, ?SDL_OPENGL_EXTS_HRL + 147).
-define(glShaderSource, ?SDL_OPENGL_EXTS_HRL + 148).
-define(glUseProgram, ?SDL_OPENGL_EXTS_HRL + 149).
-define(glUniform1f, ?SDL_OPENGL_EXTS_HRL + 150).
-define(glUniform2f, ?SDL_OPENGL_EXTS_HRL + 151).
-define(glUniform3f, ?SDL_OPENGL_EXTS_HRL + 152).
-define(glUniform4f, ?SDL_OPENGL_EXTS_HRL + 153).
-define(glUniform1i, ?SDL_OPENGL_EXTS_HRL + 154).
-define(glUniform2i, ?SDL_OPENGL_EXTS_HRL + 155).
-define(glUniform3i, ?SDL_OPENGL_EXTS_HRL + 156).
-define(glUniform4i, ?SDL_OPENGL_EXTS_HRL + 157).
-define(glUniform1fv, ?SDL_OPENGL_EXTS_HRL + 158).
-define(glUniform2fv, ?SDL_OPENGL_EXTS_HRL + 159).
-define(glUniform3fv, ?SDL_OPENGL_EXTS_HRL + 160).
-define(glUniform4fv, ?SDL_OPENGL_EXTS_HRL + 161).
-define(glUniform1iv, ?SDL_OPENGL_EXTS_HRL + 162).
-define(glUniform2iv, ?SDL_OPENGL_EXTS_HRL + 163).
-define(glUniform3iv, ?SDL_OPENGL_EXTS_HRL + 164).
-define(glUniform4iv, ?SDL_OPENGL_EXTS_HRL + 165).
-define(glUniformMatrix2fv, ?SDL_OPENGL_EXTS_HRL + 166).
-define(glUniformMatrix3fv, ?SDL_OPENGL_EXTS_HRL + 167).
-define(glUniformMatrix4fv, ?SDL_OPENGL_EXTS_HRL + 168).
-define(glValidateProgram, ?SDL_OPENGL_EXTS_HRL + 169).
-define(glVertexAttrib1dv, ?SDL_OPENGL_EXTS_HRL + 170).
-define(glVertexAttrib1fv, ?SDL_OPENGL_EXTS_HRL + 171).
-define(glVertexAttrib1sv, ?SDL_OPENGL_EXTS_HRL + 172).
-define(glVertexAttrib2dv, ?SDL_OPENGL_EXTS_HRL + 173).
-define(glVertexAttrib2fv, ?SDL_OPENGL_EXTS_HRL + 174).
-define(glVertexAttrib2sv, ?SDL_OPENGL_EXTS_HRL + 175).
-define(glVertexAttrib3dv, ?SDL_OPENGL_EXTS_HRL + 176).
-define(glVertexAttrib3fv, ?SDL_OPENGL_EXTS_HRL + 177).
-define(glVertexAttrib3sv, ?SDL_OPENGL_EXTS_HRL + 178).
-define(glVertexAttrib4Nbv, ?SDL_OPENGL_EXTS_HRL + 179).
-define(glVertexAttrib4Niv, ?SDL_OPENGL_EXTS_HRL + 180).
-define(glVertexAttrib4Nsv, ?SDL_OPENGL_EXTS_HRL + 181).
-define(glVertexAttrib4Nub, ?SDL_OPENGL_EXTS_HRL + 182).
-define(glVertexAttrib4Nubv, ?SDL_OPENGL_EXTS_HRL + 183).
-define(glVertexAttrib4Nuiv, ?SDL_OPENGL_EXTS_HRL + 184).
-define(glVertexAttrib4Nusv, ?SDL_OPENGL_EXTS_HRL + 185).
-define(glVertexAttrib4bv, ?SDL_OPENGL_EXTS_HRL + 186).
-define(glVertexAttrib4dv, ?SDL_OPENGL_EXTS_HRL + 187).
-define(glVertexAttrib4fv, ?SDL_OPENGL_EXTS_HRL + 188).
-define(glVertexAttrib4iv, ?SDL_OPENGL_EXTS_HRL + 189).
-define(glVertexAttrib4sv, ?SDL_OPENGL_EXTS_HRL + 190).
-define(glVertexAttrib4ubv, ?SDL_OPENGL_EXTS_HRL + 191).
-define(glVertexAttrib4uiv, ?SDL_OPENGL_EXTS_HRL + 192).
-define(glVertexAttrib4usv, ?SDL_OPENGL_EXTS_HRL + 193).
-define(glVertexAttribPointer, ?SDL_OPENGL_EXTS_HRL + 194).
-define(glWeightbv, ?SDL_OPENGL_EXTS_HRL + 195).
-define(glWeightsv, ?SDL_OPENGL_EXTS_HRL + 196).
-define(glWeightiv, ?SDL_OPENGL_EXTS_HRL + 197).
-define(glWeightfv, ?SDL_OPENGL_EXTS_HRL + 198).
-define(glWeightdv, ?SDL_OPENGL_EXTS_HRL + 199).
-define(glWeightubv, ?SDL_OPENGL_EXTS_HRL + 200).
-define(glWeightusv, ?SDL_OPENGL_EXTS_HRL + 201).
-define(glWeightuiv, ?SDL_OPENGL_EXTS_HRL + 202).
-define(glWeightPointer, ?SDL_OPENGL_EXTS_HRL + 203).
-define(glVertexBlend, ?SDL_OPENGL_EXTS_HRL + 204).
-define(glCurrentPaletteMatrix, ?SDL_OPENGL_EXTS_HRL + 205).
-define(glMatrixIndexubv, ?SDL_OPENGL_EXTS_HRL + 206).
-define(glMatrixIndexusv, ?SDL_OPENGL_EXTS_HRL + 207).
-define(glMatrixIndexuiv, ?SDL_OPENGL_EXTS_HRL + 208).
-define(glMatrixIndexPointer, ?SDL_OPENGL_EXTS_HRL + 209).
-define(glProgramString, ?SDL_OPENGL_EXTS_HRL + 210).
-define(glBindProgram, ?SDL_OPENGL_EXTS_HRL + 211).
-define(glDeletePrograms, ?SDL_OPENGL_EXTS_HRL + 212).
-define(glGenPrograms, ?SDL_OPENGL_EXTS_HRL + 213).
-define(glProgramEnvParameter4dv, ?SDL_OPENGL_EXTS_HRL + 214).
-define(glProgramEnvParameter4fv, ?SDL_OPENGL_EXTS_HRL + 215).
-define(glProgramLocalParameter4dv, ?SDL_OPENGL_EXTS_HRL + 216).
-define(glProgramLocalParameter4fv, ?SDL_OPENGL_EXTS_HRL + 217).
-define(glGetProgramEnvParameterdv, ?SDL_OPENGL_EXTS_HRL + 218).
-define(glGetProgramEnvParameterfv, ?SDL_OPENGL_EXTS_HRL + 219).
-define(glGetProgramLocalParameterdv, ?SDL_OPENGL_EXTS_HRL + 220).
-define(glGetProgramLocalParameterfv, ?SDL_OPENGL_EXTS_HRL + 221).
-define(glGetProgramString, ?SDL_OPENGL_EXTS_HRL + 222).
-define(glDeleteObjectARB, ?SDL_OPENGL_EXTS_HRL + 223).
-define(glGetHandle, ?SDL_OPENGL_EXTS_HRL + 224).
-define(glDetachObjectARB, ?SDL_OPENGL_EXTS_HRL + 225).
-define(glCreateShaderObjectARB, ?SDL_OPENGL_EXTS_HRL + 226).
-define(glCreateProgramObjectARB, ?SDL_OPENGL_EXTS_HRL + 227).
-define(glAttachObjectARB, ?SDL_OPENGL_EXTS_HRL + 228).
-define(glUseProgramObjectARB, ?SDL_OPENGL_EXTS_HRL + 229).
-define(glGetObjectParameterfv, ?SDL_OPENGL_EXTS_HRL + 230).
-define(glGetObjectParameteriv, ?SDL_OPENGL_EXTS_HRL + 231).
-define(glGetInfoLog, ?SDL_OPENGL_EXTS_HRL + 232).
-define(glGetAttachedObjectsARB, ?SDL_OPENGL_EXTS_HRL + 233).
-define(glStencilOpSeparateATI, ?SDL_OPENGL_EXTS_HRL + 234).
-define(glStencilFuncSeparateATI, ?SDL_OPENGL_EXTS_HRL + 235).
-define(glIsRenderbufferEXT, ?SDL_OPENGL_EXTS_HRL + 236).
-define(glBindRenderbufferEXT, ?SDL_OPENGL_EXTS_HRL + 237).
-define(glDeleteRenderbuffersEXT, ?SDL_OPENGL_EXTS_HRL + 238).
-define(glGenRenderbuffersEXT, ?SDL_OPENGL_EXTS_HRL + 239).
-define(glRenderbufferStorageEXT, ?SDL_OPENGL_EXTS_HRL + 240).
-define(glGetRenderbufferParameterivEXT, ?SDL_OPENGL_EXTS_HRL + 241).
-define(glIsFramebufferEXT, ?SDL_OPENGL_EXTS_HRL + 242).
-define(glBindFramebufferEXT, ?SDL_OPENGL_EXTS_HRL + 243).
-define(glDeleteFramebuffersEXT, ?SDL_OPENGL_EXTS_HRL + 244).
-define(glGenFramebuffersEXT, ?SDL_OPENGL_EXTS_HRL + 245).
-define(glCheckFramebufferStatusEXT, ?SDL_OPENGL_EXTS_HRL + 246).
-define(glFramebufferTexture1DEXT, ?SDL_OPENGL_EXTS_HRL + 247).
-define(glFramebufferTexture2DEXT, ?SDL_OPENGL_EXTS_HRL + 248).
-define(glFramebufferTexture3DEXT, ?SDL_OPENGL_EXTS_HRL + 249).
-define(glFramebufferRenderbufferEXT, ?SDL_OPENGL_EXTS_HRL + 250).
-define(glGetFramebufferAttachmentParameterivEXT, ?SDL_OPENGL_EXTS_HRL + 251).
-define(glGenerateMipmapEXT, ?SDL_OPENGL_EXTS_HRL + 252).
